# C2 Modal
### Overview
Flexible modal that has built-in close and open buttons, header, body and customizable options

### Props
| Props                 | Type        | Default         |
| --------------------- | ----------- | --------------- |
| backgroundOverlayColor| String      | rgba(0,0,0,0.7) |
| backgroundColor       | String      | #fff            |
| closeBtnClasses       | String      |                 |
| openBtnClasses        | String      |                 |
| transitionType        | String      | zoom            |
| wrapperClasses        | String      |                 |
| headerClasses         | String      |                 |
| maxWidth              | Number      | 1024            |
| hideOpenBtn           | Boolean     | true            |

### Slots
| Name                  |
| --------------------- |
| open-btn              |
| close-btn             |
| header                |
| body                  |

### Code snippet
```
    <c2-modal
        ref="sharedModal"
        :background-overlay-color="'rgba(0,0,0,0.8)'"
        :open-btn-classes="'flex items-center justify-center p-2'"
        :close-btn-classes="'flex items-center justify-center p-2'"
        :header-classes="'flex items-end justify-between'"
        :wrapper-classes="'p-4'"
        :max-width="1280"
        @modalOpened="modalOpened"
        @modalClosed="modalClosed"
    >
        <template v-slot:open-btn>
            <span class="text">Open Modal</span>
            <span class="pl-2 icon">+</span>
        </template>

        <template v-slot:close-btn>
            <span class="sr-only">Close Modal</span>
            <span class="icon">X</span>
        </template>

        <template v-slot:header>
            <h2 class="text-2xl">
                Optional Header Title Slot
            </h2>
        </template>

        <template v-slot:body>
            <div class="pt-4">
                <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.</p>
                <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.</p>
                <div class="flex justify-end">
                    <button 
                        class="mt-4 text-2xl"
                        @click="$refs.sharedModal.closeModal()"
                    >
                        Example Custom Cancel Button
                    </button>
                </div>
            </div>
        </template>
    </c2-modal>
```
